==> haskell-x509-store-1.6.7-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.7
id: x509-store-1.6.7-G986kl4ujQjFFn5YKMuPr5
key: x509-store-1.6.7-G986kl4ujQjFFn5YKMuPr5
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: 7b830b51d1cc0ed9f84e9eddd88cf42f
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-store-1.6.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-store-1.6.7
hs-libraries: HSx509-store-1.6.7-G986kl4ujQjFFn5YKMuPr5
depends:
    asn1-encoding-0.9.5-BJSvqDJDx54IPJiXnFLbIv
    asn1-types-0.3.2-9EHsiBYRqUhKidaP0Vcp2k base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-FS3gsWgPcOyD5QEljQG96B
    x509-1.7.5-2xExHLJ3VNlBZRhBywKbfo
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.7-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.7
id: x509-store-1.6.7-IP7GYY2iKNRHVC0i3rJ2FU
key: x509-store-1.6.7-IP7GYY2iKNRHVC0i3rJ2FU
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: e80ef579985d15e41b1d355e92a2b3e4
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-store-1.6.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-store-1.6.7
hs-libraries: HSx509-store-1.6.7-IP7GYY2iKNRHVC0i3rJ2FU
depends:
    asn1-encoding-0.9.5-JlMVXuzAd3r1xeJzCIDfY5
    asn1-types-0.3.2-662ZFPfVm6V3hVAaeDyZld base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-FS3gsWgPcOyD5QEljQG96B
    x509-1.7.5-CTIlogbzSX5AoCOzcpZ4iY
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
